@@ -69,8 +69,7 @@ class BasicTestCase(unittest.TestCase):
 
     def test_generic(self) -> None:
         try:
-            from typing import TypeVar
-
+            from typing import TypeVar  # usort: skip wants trailing whitespace
             from .. import Generic, ListVariadic
             from ..type_variable_operators import Concatenate
 
